archivist

package module
v0.0.0-...-9177b5d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 4, 2015 License: MIT Imports: 7 Imported by: 0

README

archivist

Straightforward zipping for golang

go get github.com/Varjelus/archivist

Tested on Windows 10 64-bit and Linux (ElementaryOS) 64-bit

Usage

import github.com/Varjelus/archivist

Methods

archivist.[method](sourcePath, destinationPath), handle error

  • Zip
  • Unzip
  • Tar
  • Untar

Simple, but not yet adapting so well to different cases.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SetBufferSize

func SetBufferSize(size int)

func SetFileMode

func SetFileMode(mode os.FileMode)

func Tar

func Tar(src, dst string) error

func Untar

func Untar(src, dst string) error

func Unzip

func Unzip(src, dst string) error

Unzip is an exported method which sanitizes io paths and starts unzipping

func Zip

func Zip(src, dst string) error

Zip is an exported method which sanitizes io paths and starts archiving

Types

This section is empty.

Jump to